@@ -13,7 +13,7 @@ import inspect
 from uuid import uuid4
 
 from . import RuleConst as Const
-from .providers import message_router_factory, subject_factory
+from .providers import event_router_factory, subject_factory
 
 import sys
 import traceback
@@ -25,6 +25,8 @@ logger = logging.getLogger("__core__")
 from .providers import exceptions_dumpers_factory
 import jsonpatch
 
+from collections.abc import Mapping
+
 class Rule:
 
     def __init__(self, name, description=""):
@@ -46,59 +48,65 @@ class Rule:
     def set_finally(self, finally_):
         self._finally.extend(finally_)
 
-    def _process(self, message, subject, payload):
+    def _process(self, event_type, subject, payload):
 
         def __clean(dd):
             del dd[Const.PROCESS_ID]
-            del dd[Const.MESSAGE]
+            del dd[Const.TYPE]
             del dd[Const.SUBJECT]
-            del dd[Const.RULE_NAME]
+            del dd[Const.RULENAME]
             del dd[Const.SECTION]
-            dd[Const.PAYLOAD].pop("_event_info", None)
+            dd.get(Const.PAYLOAD, {}).pop("_event_info", None)
             return dd
 
         def __copy_list(ll):
-            from collections.abc import Mapping
             dst = []
             for el in ll:
                 if isinstance(el, Mapping):
                     dst.append(__copy(el))
-                elif isinstance(el, list):
+                elif isinstance(el, (list, tuple)):
                     dst.append(__copy_list(el))
-                else:
+                elif inspect.isfunction(el):
+                    dst.append(el.__name__)
+                elif isinstance(el, (bool, int, float, str)) or el is None:
                     dst.append(el)
+                else:
+                    dst.append(str(el))
             return dst
 
         def __copy(pp):
-            from collections.abc import Mapping
             cp = {}
             for k, v in pp.items():
                 if isinstance(v, Mapping):
                     cp[k] = {}
                     cp[k] = __copy(v)
-                elif isinstance(v, list):
+                elif isinstance(v, (list, tuple)):
                     cp[k] = __copy_list(v)
-                else:
+                elif inspect.isfunction(v):
+                    cp[k] = v.__name__
+                elif isinstance(v, (bool, int, float, str)) or v is None:
                     cp[k] = v
+                else:
+                    cp[k] = str(v)
             return cp
 
-        logger.debug("process {0} for {1}".format(message, self.name))
+        logger.debug("process {0} for {1}".format(event_type, self.name))
 
-        if type(subject) == str:
+        if isinstance(subject, str):
             subject = subject_factory(subject)
 
-        from .providers import results_rx_factory
+        from .providers import proc_events_rx_factory
 
-        results_rx = results_rx_factory()  # one event for each processed rule
+        proc_events_rx = proc_events_rx_factory()  # one event for each processed rule
 
         process_id = str(uuid4())
         payload_copy = __copy(payload)
         event_info = payload_copy.pop("_event_info", {})
 
         res_full = {
-            Const.MESSAGE: message,
+            Const.TYPE: event_type,
             Const.SUBJECT: str(subject.name),
-            Const.RULE_NAME: self.name,
+            Const.RULENAME: self.name,
             Const.PAYLOAD: payload_copy,
             Const.FILTERS: [],
             Const.PROCESSING: [],
@@ -106,57 +114,60 @@ class Rule:
             Const.EVENT_INFO: event_info,
         }
 
-        last_payload = payload_copy
+        last_payload = __copy(payload)
 
         res_in = {}
+        processed_args = {}
+        processed_kwargs = {}
         try:
             for _c in self._filters:
                 if inspect.isclass(_c):
                     _c = _c()
                 _cinst_name = _c.__class__.__name__
                 _cinst = type(_cinst_name, (_c.__class__,), {})()
-                _cinst.message = message
+                _cinst.type = event_type
                 _cinst.subject = subject
                 _cinst.payload = payload
                 res_in = {
                     Const.PROCESS_ID: process_id,
-                    Const.MESSAGE: message,
+                    Const.TYPE: event_type,
                     Const.SUBJECT: str(subject.name),
-                    Const.RULE_NAME: self.name,
+                    Const.RULENAME: self.name,
                     Const.SECTION: Const.FILTERS,
                     Const.FUNC_NAME: _cinst_name,
-                    Const.PAYLOAD: payload.copy(),
-                    Const.ARGS: _c._args,
-                    Const.KWARGS: _c._kwargs,
+                    Const.PAYLOAD: __copy(payload),
+                    Const.ARGS: __copy_list(_c._args),
+                    Const.KWARGS: __copy(_c._kwargs),
                 }
                 logger.debug("> processing: {0}".format(res_in))
                 try:
-                    res = _cinst.execute(*_c._get_args(_cinst), **_c._get_kwargs(_cinst))
+                    processed_args = _c._get_args(_cinst)
+                    processed_kwargs = _c._get_kwargs(_cinst)
+                    res = _cinst.execute(*processed_args, **processed_kwargs)
                 except TypeError as ex:
                     msg = "{} in {}: ".format(_cinst_name, self.name)
                     raise TypeError(msg + str(ex))
 
-                payload_patches = jsonpatch.JsonPatch.from_diff(last_payload, payload)
-                last_payload = __copy(payload)
+                payload_copy = __copy(payload)
+                payload_patches = jsonpatch.JsonPatch.from_diff(last_payload, payload_copy).patch
+                last_payload = payload_copy
                 res_out = {
                     Const.PROCESS_ID: res_in[Const.PROCESS_ID],
-                    Const.MESSAGE: res_in[Const.MESSAGE],
+                    Const.TYPE: res_in[Const.TYPE],
                     Const.SUBJECT: res_in[Const.SUBJECT],
-                    Const.RULE_NAME: res_in[Const.RULE_NAME],
+                    Const.RULENAME: res_in[Const.RULENAME],
                     Const.SECTION: res_in[Const.SECTION],
                     Const.FUNC_NAME: res_in[Const.FUNC_NAME],
-                    Const.PAYLOAD: {
-                        Const.PAYLOAD_DIFFS: payload_patches.patch
-                    },
-                    Const.ARGS: res_in[Const.ARGS],
-                    Const.KWARGS: res_in[Const.KWARGS],
+                    Const.PAYLOAD_DIFFS: payload_patches,
+                    Const.ARGS: __copy_list(processed_args),
+                    Const.KWARGS: __copy(processed_kwargs),
                     Const.RETURNS: res
                 }
-                logger.debug("< processed: {0}".format({'payload': res_out[Const.PAYLOAD], 'returns': res_out[Const.RETURNS]}))
+                logger.debug("< processed: {0}".format({'payload_diffs': res_out[Const.PAYLOAD_DIFFS], 'returns': res_out[Const.RETURNS]}))
                 res_full[Const.FILTERS].append(__clean(res_out))
                 if not res:
                     res_full[Const.PROCESSED] = False
-                    results_rx.on_next(res_full)
+                    proc_events_rx.on_next(res_full)
                     return
 
             res_full[Const.PROCESSED] = True
@@ -166,65 +177,64 @@ class Rule:
                     _c = _c()
                 _cinst_name = _c.__class__.__name__
                 _cinst = type(_cinst_name, (_c.__class__,), {})()
-                _cinst.message = message
+                _cinst.type = event_type
                 _cinst.subject = subject
                 _cinst.payload = payload
                 res_in = {
                     Const.PROCESS_ID: process_id,
-                    Const.MESSAGE: message,
+                    Const.TYPE: event_type,
                     Const.SUBJECT: str(subject.name),
-                    Const.RULE_NAME: self.name,
+                    Const.RULENAME: self.name,
                     Const.SECTION: Const.PROCESSING,
                     Const.FUNC_NAME: _cinst_name,
-                    Const.PAYLOAD: payload.copy(),
-                    Const.ARGS: _c._args,
-                    Const.KWARGS: _c._kwargs,
+                    Const.PAYLOAD: __copy(payload),
+                    Const.ARGS: __copy_list(_c._args),
+                    Const.KWARGS: __copy(_c._kwargs),
                 }
                 logger.debug("> processing: {0}".format(res_in))
                 try:
-                    res = _cinst.execute(*_c._get_args(_cinst), **_c._get_kwargs(_cinst))
+                    processed_args = _c._get_args(_cinst)
+                    processed_kwargs = _c._get_kwargs(_cinst)
+                    res = _cinst.execute(*processed_args, **processed_kwargs)
                 except TypeError as ex:
                     msg = "{} in {}: ".format(_cinst_name, self.name)
                     raise TypeError(msg + str(ex))
-                payload_patches = jsonpatch.JsonPatch.from_diff(last_payload, payload)
-                last_payload = __copy(payload)
+                payload_copy = __copy(payload)
+                payload_patches = jsonpatch.JsonPatch.from_diff(last_payload, payload_copy).patch
+                last_payload = payload_copy
                 res_out = {
                     Const.PROCESS_ID: res_in[Const.PROCESS_ID],
-                    Const.MESSAGE: res_in[Const.MESSAGE],
+                    Const.TYPE: res_in[Const.TYPE],
                     Const.SUBJECT: res_in[Const.SUBJECT],
-                    Const.RULE_NAME: res_in[Const.RULE_NAME],
+                    Const.RULENAME: res_in[Const.RULENAME],
                     Const.SECTION: res_in[Const.SECTION],
                     Const.FUNC_NAME: res_in[Const.FUNC_NAME],
-                    Const.PAYLOAD: {
-                        Const.PAYLOAD_DIFFS: payload_patches.patch
-                    },
-                    Const.ARGS: res_in[Const.ARGS],
-                    Const.KWARGS: res_in[Const.KWARGS],
+                    Const.PAYLOAD_DIFFS: payload_patches,
+                    Const.ARGS: __copy_list(processed_args),
+                    Const.KWARGS: __copy(processed_kwargs),
                     Const.RETURNS: res,
                 }
-                logger.debug("< processed: {0}".format({'payload': res_out[Const.PAYLOAD], 'returns': res_out[Const.RETURNS]}))
+                logger.debug("< processed: {0}".format({'payload_diffs': res_out[Const.PAYLOAD_DIFFS], 'returns': res_out[Const.RETURNS]}))
                 res_full[Const.PROCESSING].append(__clean(res_out))
 
-            results_rx.on_next(res_full)
+            proc_events_rx.on_next(res_full)
 
         except Exception as e:
             logger.error("catched exception of type {0} ({1})".format(type(e), getattr(e, 'message', str(e))))
-            if results_rx:
-                payload_patches = jsonpatch.JsonPatch.from_diff(last_payload, payload)
-
+            if proc_events_rx:
+                payload_copy = __copy(payload)
+                payload_patches = jsonpatch.JsonPatch.from_diff(last_payload, payload_copy).patch
                 type_, value_, traceback_ = sys.exc_info()
                 res_out = {
                     Const.PROCESS_ID: res_in[Const.PROCESS_ID],
-                    Const.MESSAGE: res_in[Const.MESSAGE],
+                    Const.TYPE: res_in[Const.TYPE],
                     Const.SUBJECT: res_in[Const.SUBJECT],
-                    Const.RULE_NAME: res_in[Const.RULE_NAME],
+                    Const.RULENAME: res_in[Const.RULENAME],
                     Const.SECTION: res_in[Const.SECTION],
                     Const.FUNC_NAME: res_in[Const.FUNC_NAME],
-                    Const.PAYLOAD: {
-                        Const.PAYLOAD_DIFFS: payload_patches.patch
-                    },
-                    Const.ARGS: res_in[Const.ARGS],
-                    Const.KWARGS: res_in[Const.KWARGS],
+                    Const.PAYLOAD_DIFFS: payload_patches,
+                    Const.ARGS: __copy_list(processed_args),
+                    Const.KWARGS: __copy(processed_kwargs),
                     Const.RETURNS: None,
                     Const.EXCEPTION: ".".join([type(e).__module__, type(e).__name__]),
                     Const.EXC_INFO: traceback.format_exception(type_, value_, traceback_),
@@ -234,22 +244,21 @@ class Rule:
                 logger.debug("# unprocessed: {0}".format(res_out))
                 res_full[Const.GOT_ERRORS] = True
                 res_full[res_out[Const.SECTION]].append(__clean(res_out))
-                results_rx.on_next(res_full)
+                proc_events_rx.on_next(res_full)
 
 
 class RuleFactory:
 
     @staticmethod
-    def create(rulename: object, description: object = "", subscribe_to: object = None, ruledata: object = {}) -> object:
+    def create(name: object, description: object = "", subscribe_to: object = None, data: object = {}) -> object:
 
-        rule = Rule(rulename, description)
+        rule = Rule(name, description)
 
-        rule.set_filters(ruledata.get(Const.FILTERS, []))
-        rule.set_processing(ruledata.get(Const.PROCESSING, []))
-        rule.set_finally(ruledata.get(Const.FINALLY, []))
+        rule.set_filters(data.get(Const.FILTERS, []))
+        rule.set_processing(data.get(Const.PROCESSING, []))
+        rule.set_finally(data.get(Const.FINALLY, []))
 
         if isinstance(subscribe_to, str):
             subscribe_to = (subscribe_to,)
         for el in subscribe_to:
-            message_router_factory().register(rule, el)
-        #return message_router_factory().register(rule, subscribe_to)
+            event_router_factory().register(rule, el)
